====================
Async API Reference
====================

Asynchronous API using Tornado framework.

Publisher & Subscriber
======================

AsyncPublisher
--------------

.. autoclass:: gntplib.async_gntp.AsyncPublisher
   :members:
   :special-members: __init__
   :show-inheritance:

AsyncSubscriber
---------------

.. autoclass:: gntplib.async_gntp.AsyncSubscriber
   :members:
   :special-members: __init__
   :show-inheritance:

Client & Connection
===================

AsyncGNTPClient
---------------

.. autoclass:: gntplib.async_gntp.AsyncGNTPClient
   :members:
   :special-members: __init__
   :show-inheritance:

AsyncGNTPConnection
-------------------

.. autoclass:: gntplib.async_gntp.AsyncGNTPConnection
   :members:
   :special-members: __init__
   :show-inheritance:

Resources
=========

AsyncResource
-------------

.. autoclass:: gntplib.async_gntp.AsyncResource
   :members:
   :special-members: __init__, __repr__
   :show-inheritance:

Utility Functions
=================

.. autofunction:: gntplib.async_gntp.fetch_async_resources_in_parallel

.. autofunction:: gntplib.async_gntp.collect_async_resources